Index: fetch_configs/naclports.py |
diff --git a/recipes/naclports.py b/fetch_configs/naclports.py |
similarity index 89% |
rename from recipes/naclports.py |
rename to fetch_configs/naclports.py |
index 10a0b28fb60030963bb23bbd2809c8a5479c4e5a..e631f2254639729b4e732c0cde7ae13ed18d9a79 100644 |
--- a/recipes/naclports.py |
+++ b/fetch_configs/naclports.py |
@@ -4,13 +4,13 @@ |
import sys |
-import recipe_util # pylint: disable=F0401 |
+import config_util # pylint: disable=F0401 |
# This class doesn't need an __init__ method, so we disable the warning |
# pylint: disable=W0232 |
-class Naclports(recipe_util.Recipe): |
- """Basic Recipe class for naclports.""" |
+class Naclports(config_util.Config): |
+ """Basic Config class for naclports.""" |
@staticmethod |
def fetch_spec(props): |